//
//  ViewController.swift
//  SmartAxis_AddLabelsRunTime
//
//  Created by Max Rivlin on 5/9/16.
//  Copyright © 2016 Infragistics. All rights reserved.
//

import UIKit
import IGChart

class ViewController: UIViewController, IGChartViewDelegate {

    var _chart: IGChartView!
    var _series: IGLineSeries!
    var _xAxis: IGCategoryXAxis!
    var _dsh: IGCategorySeriesDataSourceHelper!
    var _data: NSMutableArray!
    var _dateFormatter: NSDateFormatter = NSDateFormatter()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        _data = NSMutableArray()
        
        _dsh = IGCategorySeriesDataSourceHelper(data: _data as [AnyObject], andValuePath: "value")
        _dsh.labelPath = "label"
        
        _chart = IGChartView(frame: self.view.bounds)
        _chart.delegate = self
        _chart.horizontalAutoMargin = 50
        
        _series = _chart.addSeriesForType(IGLineSeries.self, usingKey: "series", withDataSource: _dsh, firstAxisKey: "x", secondAxisKey: "y") as! IGLineSeries
        
        _xAxis = _chart.findAxisByKey("x") as! IGCategoryXAxis
        _xAxis.useSmartAxisPanel = true
        _xAxis.smartAxisAngle = 45
        
        self.view.addSubview(_chart)

        _dateFormatter.dateStyle = NSDateFormatterStyle.ShortStyle
        _dateFormatter.timeStyle = NSDateFormatterStyle.MediumStyle

        NSTimer.scheduledTimerWithTimeInterval(1, target: self, selector: #selector(tick), userInfo: nil, repeats: true)
    }

    func tick()
    {
        let value: CGFloat = CGFloat(arc4random()%5)
        let timestamp: NSDate = NSDate(timeIntervalSinceNow: 0)
        let label: String = _dateFormatter.stringFromDate(timestamp)
        
        let obj: ChartData = ChartData(value: value, timestamp: timestamp, label: label)
        _data.addObject(obj)
        _dsh.data = _data as [AnyObject]
        
        _chart.insertItemAtIndex(_series.dataPoints.count, withSource: _dsh)
    }
}

class ChartData: NSObject
{
    var value: CGFloat = 0
    var timestamp: NSDate
    var label: String

    init(value: CGFloat, timestamp: NSDate, label: String) {
       self.value = value
        self.timestamp = timestamp
        self.label = label
    }
}